/**
 * 管理后台端 企业相关 
 * 包括 在孵企业页面
 * 包括 企业融资页面 
 */

import * as asyncHandler from 'express-async-handler';
import * as enterpriseBiz from '../../biz/enterprise/enterprise';
import * as financingBiz from '../../biz/enterprise/financing';
import { checkParamaterType, getTimeKey } from '../../util/tools';
import { checkGuanWeiHuiToken } from '../../middleware/user';


export function setRouter(httpServer) {
    httpServer.post('/admin/enterprise/list',checkGuanWeiHuiToken, asyncHandler(getEnterpriseList));
    httpServer.post('/admin/enterprise/financinglist',checkGuanWeiHuiToken, asyncHandler(getFinancingList));
    httpServer.post('/admin/enterprise/affiliationfuhuaqi',checkGuanWeiHuiToken,asyncHandler(affiliationFuHuaQi));
    httpServer.post('/admin/data/output/enterprise',checkGuanWeiHuiToken, asyncHandler(outPutEnterpriseData));
    httpServer.post('/admin/data/output/financing',checkGuanWeiHuiToken, asyncHandler(outPutFinancingData));
}


/**
 * 后台管理 获取在孵企业信息列表 
 * @param req 
 * @param res 
 */
async function getEnterpriseList(req, res) {
    let reqConf = {createType: 'Number', fuHuaQiUscc: 'String', industry: '[Number]', isNaturalPersonHolding: 'Number', page: 'Number' };
    let { createType, fuHuaQiUscc, industry, isNaturalPersonHolding, page } = checkParamaterType(reqConf, req.body);

    let result = await enterpriseBiz.enterpriseList(createType, fuHuaQiUscc, industry, isNaturalPersonHolding, page);
    res.success(result);
}


/**
 * 后台管理 获取融资企业信息列表 
 * @param req 
 * @param res
 */
async function getFinancingList(req, res) {
    let reqConf = {monthData: 'String', fuHuaQiName: 'String', fuHuaQiInvestment: 'Number', industry: '[Number]', page: 'Number' };
    let {monthData, fuHuaQiName, industry, fuHuaQiInvestment, page} = checkParamaterType(reqConf, req.body);

    let result = await financingBiz.financingList(monthData, fuHuaQiName, industry, fuHuaQiInvestment, page);
    res.success(result);
}


/**
 * 所属孵化器
 * 下拉框
 * @param req 
 * @param res 
 */
async function affiliationFuHuaQi(req, res) {
    let  result = await enterpriseBiz.getAffiliationFuHuaQi();
    res.success(result);
}


/**
 * 导出在孵企业数据
 * @param req 
 * @param res 
 */
async function outPutEnterpriseData(req, res) {
    let reqConf = {createType: 'Number', fuHuaQiUscc: 'String', industry: '[Number]', isNaturalPersonHolding: 'Number', type:'Number' };
    let { createType, fuHuaQiUscc, industry, isNaturalPersonHolding, page, type } = checkParamaterType(reqConf, req.body);
    
    let dataList = await enterpriseBiz.outPutEnterpriseData(createType, fuHuaQiUscc, industry, isNaturalPersonHolding, type);

    let keyList = [
        "name", "createTime", "fuhuaqiUscc", "uscc", "industry", "logonTime",
        "firstIncubationTime", "timeOfImmigration", "isNaturalPersonHolding", "oldLogonAdd",
        "logonAdd", "operatingAdd", "leasedArea"
    ];
    let titleList = [
        "企业名称", "入库时间", "所属孵化器", "统一信用代码", "行业领域",
        "注册时间", "首次入孵时间", "迁入时间", "是否自然人控股", "迁入前注册地址",
        "注册地址", "经营地址", "租赁面积（平方米）"
    ];
    let result = [titleList];
    dataList.forEach(info => {
        let subList = [];
        keyList.forEach(subInfo => {
            subList.push(info[subInfo] || '');
        });
        result.push(subList);
    });

    let name = `在孵企业${getTimeKey()}.xlsx`;

    res.success({name, data:result});
}


/**
 * 导出企业融资数据
 * @param req 
 * @param res 
 */
async function outPutFinancingData(req, res) {
    let reqConf = {monthData: 'String', fuHuaQiName: 'String', fuHuaQiInvestment: 'Number', industry: '[Number]', type:'Number' };
    let {monthData, fuHuaQiName, industry, fuHuaQiInvestment, type} = checkParamaterType(reqConf, req.body);
    
    let dataList =  await financingBiz.outPutFinancingList(monthData, fuHuaQiName, industry, fuHuaQiInvestment, type);

    let keyList = [
        "name", "logonAdd", "operatingAdd", "financingAmount","investmentInstitutionsName",
        "timeToObtainInvestment", "fuHuaQiInvestment", "fuHuaQiInvestmentAmount", "fuHuaQiInvestmentStyle", "createTime"
    ];
    let titleList = [
        "企业名称","注册地址","经营地址","融资金额(万元)","投资机构名称","获得投资时间",
        "孵化器是否投资","孵化器投资金额(万元)","孵化器投资方式","录入时间",
    ];
    let result = [titleList];
    dataList.forEach(info => {
        let subList = [];
        keyList.forEach(subInfo => {
            subList.push(info[subInfo] || '');
        });
        result.push(subList);
    });

    let name = `融资企业${getTimeKey()}.xlsx`;

    res.success({name, data:result});
}
