/**
 * 管理后台端 孵化器信息 
 */

import * as asyncHandler from 'express-async-handler';
import * as userBiz from '../../biz/fuHuqQi/user';
import * as baseBiz from '../../biz/fuHuqQi/base';
import { checkParamaterType, checkReqParam, getTimeKey } from '../../util/tools';
import { monthTableList } from '../../biz/fuHuqQi/month';
import { checkGuanWeiHuiToken } from '../../middleware/user';
import * as monthBiz from '../../biz/fuHuqQi/month';


export function setRouter(httpServer) {
    httpServer.post('/admin/fuhuaqi/baselist',checkGuanWeiHuiToken, asyncHandler(fuHuaQiBaseList));
    httpServer.post('/admin/fuhuaqi/monthoccupancyrate',checkGuanWeiHuiToken, asyncHandler(getMonthList));
    httpServer.post('/admin/fuhuaqi/userlist',checkGuanWeiHuiToken, asyncHandler(getFuHuaQiUserList));
    httpServer.post('/admin/fuhuaqi/updatestate',checkGuanWeiHuiToken, asyncHandler(updateState));
    httpServer.post('/admin/fuhuaqi/adduser',checkGuanWeiHuiToken,asyncHandler(addUser));
    httpServer.post('/admin/data/output/fuhuaqi',checkGuanWeiHuiToken, asyncHandler(outPutFuHuaQiData));
    httpServer.post('/admin/data/output/month',checkGuanWeiHuiToken, asyncHandler(outPutMonthData));
}


/**
 * 孵化器基本信息列表
 * @param req 
 * @param res 
 */
async function fuHuaQiBaseList(req, res) {
    let reqConf = {
        lv: 'Number', 
        institutionalNature: 'Number',//机构性质
        operationModel:"Number",//运营模式
        foundingTeam:"Number",//创业团队
        industry: 'Number', 
        page: 'Number' 
    };
    let {lv, institutionalNature, industry, operationModel, foundingTeam, page} = checkParamaterType(reqConf, req.body);
    
    let result = await baseBiz.fuHuaQiBaseList(lv, institutionalNature, industry, operationModel, foundingTeam, page);

    res.success(result);
}


/**
 * 后台管理  获取月度出租率信息列表
 * @param req 
 * @param res 
 */
async function getMonthList(req, res) {
    let  reqConf = {state: 'Number', year: 'Number', month: 'Number', page: 'Number'};
    let { state, year, month, page } = checkParamaterType(reqConf, req.body);
    
    let result = await monthTableList(state, year, month, page);
    res.success(result);
}


/**
 * 后台管理 获取孵化器账号信息列表 
 * @param req 
 * @param res 
 */
 async function getFuHuaQiUserList(req, res) {
    let reqConf = {operationName: 'String', page: 'Number' };
    let { operationName, page } = checkParamaterType(reqConf, req.body);

    let result = await userBiz.fuHuaQiUserList(operationName, page);
    res.success(result);
}


/**
 * 后台管理 修改孵化器账号状态 
 * @param req 
 * @param res 
 */
 async function updateState(req, res) {
    let reqConf = {userState: 'Boolean', uscc: 'String' };
    let { userState, uscc } = checkReqParam(reqConf, req.body);

    let result = await userBiz.updateState(uscc, userState);
    res.success(result);
}


/**
 * 后台管理 新增孵化器账号
 * @param req 
 * @param res 
 */
async function addUser(req, res) {
    let reqConf = {form: 'Object' };
    let { form } = checkReqParam(reqConf, req.body);

    let result = await userBiz.addUser(form);
    res.success(result);
}



async function outPutFuHuaQiData(req, res) {
    let reqConf = {lv: 'Number', institutionalNature: 'Number', industry: 'Number', dataType:'Number', type:'Number'};
    let { lv, institutionalNature, industry, type } = checkParamaterType(reqConf, req.body);

    let dataList = await baseBiz.outPutFuHuaQiBaseData(lv, institutionalNature, industry, type);
    
    let keyList = [
        "name","operationName","uscc","virtualEnterpriseNum","logonTime",
        "incubatedAcreage", "acreageTotal", "acreagePersonalUse", "lv", "identificationTime",
        "industry", "institutionalNature", "liaison", "liaisonPhone", "personInCharge",
        "personInChargePhone", "personInChargeAdd", "siteAcreage", "leasePrice"
    ];
    let titleList = [
        "名称", "运营机构名称", "统一信用代码", "虚拟企业数量", "注册时间",
        "在孵面积", "孵化器总面积", "孵化器自用面积", "孵化器级别", "认定时间",
        "领域", "机构性质", "联系人", "联系电话", "负责人",
        "负责人联系电话", "孵化场地地址", "孵化场地面积", "孵化场地出租单价"
    ];
    let result = [titleList];
    dataList.forEach(info => {
        let subList = [];
        keyList.forEach(subInfo => {
            subList.push(info[subInfo] || '');
        });
        result.push(subList);
    });
    let name = `孵化器列表${getTimeKey()}.xlsx`;

    res.success({name, data:result});
    
}



async function outPutMonthData(req, res) {
    let  reqConf = {state: 'Number', year: 'Number', month: 'Number', type:'Number'};
    let { state, year, month, type } = checkParamaterType(reqConf, req.body);
    
    let dataList = await monthBiz.outPutMonthTableList(state, year, month, type);

    let keyList = [
        "operationName",
        "state",
        "time",
        "occupancyRate",
    ];
    let titleList = [
        "运营机构名称","填报状态","数据月份","出租率(%)"
    ];
    let result = [titleList];
    dataList.forEach(info => {
        let subList = [];
        keyList.forEach(subInfo => {
            subList.push(info[subInfo] || '');
        });
        result.push(subList);
    });

    let name = `月度任务${getTimeKey()}.xlsx`;

    res.success({name, data:result});
}